@@ -116,7 +116,7 @@ def hedge_global_lp_position(maturity_df, get_lp_value_gain=None, lp_lower_bound
         longs_val =  maturity_df['long_payoff_fun'].values
         shorts_val = maturity_df['short_payoff_fun'].values
         x_init = np.zeros(2 * len(longs_val))
-        def to_optimize_l1_distance(x, longs_val=None, shorts_val=None,lp_lower_bound=None, lp_upper_bound=None):
+        def to_optimize_l1_distance(x, longs_val=None, shorts_val=None,lp_lower_bound=None, lp_upper_bound=None, get_lp_value_gain=None):
             l1_norm = 0
             for final_price in [lp_lower_bound + (i / 100.) * (lp_upper_bound - lp_lower_bound) for i in range(0, 100, 10)]:
                 lp_value = get_lp_value_gain(final_price)
@@ -135,7 +135,7 @@ def hedge_global_lp_position(maturity_df, get_lp_value_gain=None, lp_lower_bound
                 l1_norm = l1_norm +abs(lp_value-total_deriv_payoff)
             return l1_norm
 
-        gogo = lambda x: to_optimize_l1_distance(x, longs_val=longs_val, shorts_val=shorts_val, lp_lower_bound=lp_lower_bound, lp_upper_bound=lp_upper_bound)
+        gogo = lambda x: to_optimize_l1_distance(x, longs_val=longs_val, shorts_val=shorts_val, lp_lower_bound=lp_lower_bound, lp_upper_bound=lp_upper_bound, get_lp_value_gain=get_lp_value_gain)
         low_bound = 0.
         up_bound = +np.infty
         const_ind = Bounds(low_bound, up_bound)
@@ -162,8 +162,11 @@ def hedge_global_lp_position(maturity_df, get_lp_value_gain=None, lp_lower_bound
         maturity_df['longs_i'] = longs_i
         maturity_df['shorts_i'] = shorts_i
 
-        value_df = compute_derivatives_profile(longs_val=longs_val, shorts_val=shorts_val)
+
         if plot_html:
+            value_df = compute_derivatives_profile(longs_val=longs_val, shorts_val=shorts_val,
+                                                   lp_lower_bound=lp_lower_bound, lp_upper_bound=lp_upper_bound,
+                                                   get_lp_value_gain=get_lp_value_gain)
             fig = realtime_plotting_utility.plot_dollar_multiple_time_series(data_df=value_df,
                                                                              logy=False, split=False,
                                                                              put_on_same_scale=False,
